
-- SHUFFLE curse: shuffles the squares in the map ----------------------------

ID_CURSE_SHUFFLE=4

function shuffle_do_curse(sent)
    if sent==0 then
        u61_send_curse(ID_CURSE_SHUFFLE)
    else
        u61_register_curse(ID_CURSE_SHUFFLE,200,0)
    end
end

function shuffle_time_callback()
    local y
    local x
    local dy
    local dx
    local i
    local color
    local width
    local height

    if u61_get_curse_age(ID_CURSE_SHUFFLE)>=0 then
        width=u61_get_width()
        height=u61_get_height()

        i=u61_get_time()
        y=0
        while y<height do
            x=0
            while x<width do
                color=u61_get_square_color(x,y)
                if color>=0 then
                    dy=mod(floor(i/3),3)-1
                    dx=mod(i,3)-1
                    if x+dx>=0 and x+dx<width and (y+dy>=10 or dy>=0) and y+dy<height and u61_get_square_color(x+dx,y+dy)<0 then
                        u61_set_square_color(x,y,-1)
                        u61_set_square_color(x+dx,y+dy,color)
                    end
                    i=i+1
                end
                x=x+1
            end
            y=y+1
        end
    end
end

